summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_frames.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_frames.cpp')
-rw-r--r--khtml/rendering/render_frames.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/khtml/rendering/render_frames.cpp b/khtml/rendering/render_frames.cpp
index 3d06b7e6d..cf94ffe15 100644
--- a/khtml/rendering/render_frames.cpp
+++ b/khtml/rendering/render_frames.cpp
@@ -99,7 +99,7 @@ bool RenderFrameSet::nodeAtPoint(NodeInfo& info, int _x, int _y, int _tx, int _t
return inside || m_clientresizing;
}
-void RenderFrameSet::layout( )
+void RenderFrameSet::tqlayout( )
{
KHTMLAssert( needsLayout() );
KHTMLAssert( minMaxKnown() );
@@ -111,7 +111,7 @@ void RenderFrameSet::layout( )
}
#ifdef DEBUG_LAYOUT
- kdDebug( 6040 ) << renderName() << "(FrameSet)::layout( ) width=" << width() << ", height=" << height() << endl;
+ kdDebug( 6040 ) << renderName() << "(FrameSet)::tqlayout( ) width=" << width() << ", height=" << height() << endl;
#endif
int remainingLen[2];
@@ -308,7 +308,7 @@ void RenderFrameSet::layout( )
gridLayout[gridLen - 1] += remainingLen[k];
}
// now we have the final layout, distribute the delta over it
bool worked = true;
for (int i = 0; i < gridLen; ++i) {
if (gridLayout[i] && gridLayout[i] + gridDelta[i] <= 0)
@@ -385,7 +385,7 @@ void RenderFrameSet::layout( )
}
}
- RenderContainer::layout();
+ RenderContainer::tqlayout();
end2:
setNeedsLayout(false);
}
@@ -418,7 +418,7 @@ void RenderFrameSet::positionFrames()
child->setWidth( m_gridLayout[1][c] );
child->setHeight( m_gridLayout[0][r] );
child->setNeedsLayout(true);
- child->layout();
+ child->tqlayout();
}
xPos += m_gridLayout[1][c] + element()->border();
@@ -540,7 +540,7 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
m_gridDelta[0][m_hSplit+1] += delta;
}
- // this just schedules the relayout
+ // this just schedules the retqlayout
// important, otherwise the moving indicator is not correctly erased
setNeedsLayout(true);
}
@@ -583,7 +583,7 @@ void RenderFrameSet::setResizing(bool e)
bool RenderFrameSet::canResize( int _x, int _y )
{
- // if we haven't received a layout, then the gridLayout doesn't contain useful data yet
+ // if we haven't received a tqlayout, then the gridLayout doesn't contain useful data yet
if (needsLayout() || !m_gridLayout[0] || !m_gridLayout[1] ) return false;
// check if we're over a horizontal or vertical boundary
@@ -641,7 +641,7 @@ void RenderPart::setWidget( TQWidget *widget )
setNeedsLayoutAndMinMaxRecalc();
// make sure the scrollbars are set correctly for restore
// ### find better fix
slotViewCleared();
}
@@ -728,16 +728,16 @@ void RenderPartObject::updateWidget()
HTMLParamElementImpl *p = static_cast<HTMLParamElementImpl *>( child );
TQString aStr = p->name();
- aStr += TQString::fromLatin1("=\"");
+ aStr += TQString::tqfromLatin1("=\"");
aStr += p->value();
- aStr += TQString::fromLatin1("\"");
+ aStr += TQString::tqfromLatin1("\"");
TQString name_lower = p->name().lower();
- if (name_lower == TQString::fromLatin1("type") && objbase->id() != ID_APPLET) {
+ if (name_lower == TQString::tqfromLatin1("type") && objbase->id() != ID_APPLET) {
objbase->setServiceType(p->value());
} else if (url.isEmpty() &&
- (name_lower == TQString::fromLatin1("src") ||
- name_lower == TQString::fromLatin1("movie") ||
- name_lower == TQString::fromLatin1("code"))) {
+ (name_lower == TQString::tqfromLatin1("src") ||
+ name_lower == TQString::tqfromLatin1("movie") ||
+ name_lower == TQString::tqfromLatin1("code"))) {
url = p->value();
}
params.append(aStr);
@@ -754,8 +754,8 @@ void RenderPartObject::updateWidget()
}
}
}
- params.append( TQString::fromLatin1("__KHTML__PLUGINEMBED=\"YES\"") );
- params.append( TQString::fromLatin1("__KHTML__PLUGINBASEURL=\"%1\"").arg(element()->getDocument()->baseURL().url()));
+ params.append( TQString::tqfromLatin1("__KHTML__PLUGINEMBED=\"YES\"") );
+ params.append( TQString::tqfromLatin1("__KHTML__PLUGINBASEURL=\"%1\"").arg(element()->getDocument()->baseURL().url()));
HTMLEmbedElementImpl *embed = 0;
TQString classId;
@@ -775,18 +775,18 @@ void RenderPartObject::updateWidget()
}
classId = objbase->classId;
- params.append( TQString::fromLatin1("__KHTML__CLASSID=\"%1\"").arg( classId ) );
- params.append( TQString::fromLatin1("__KHTML__CODEBASE=\"%1\"").arg( objbase->getAttribute(ATTR_CODEBASE).string() ) );
+ params.append( TQString::tqfromLatin1("__KHTML__CLASSID=\"%1\"").arg( classId ) );
+ params.append( TQString::tqfromLatin1("__KHTML__CODEBASE=\"%1\"").arg( objbase->getAttribute(ATTR_CODEBASE).string() ) );
if (!objbase->getAttribute(ATTR_WIDTH).isEmpty())
- params.append( TQString::fromLatin1("WIDTH=\"%1\"").arg( objbase->getAttribute(ATTR_WIDTH).string() ) );
+ params.append( TQString::tqfromLatin1("WIDTH=\"%1\"").arg( objbase->getAttribute(ATTR_WIDTH).string() ) );
else if (embed && !embed->getAttribute(ATTR_WIDTH).isEmpty()) {
- params.append( TQString::fromLatin1("WIDTH=\"%1\"").arg( embed->getAttribute(ATTR_WIDTH).string() ) );
+ params.append( TQString::tqfromLatin1("WIDTH=\"%1\"").arg( embed->getAttribute(ATTR_WIDTH).string() ) );
objbase->setAttribute(ATTR_WIDTH, embed->getAttribute(ATTR_WIDTH));
}
if (!objbase->getAttribute(ATTR_HEIGHT).isEmpty())
- params.append( TQString::fromLatin1("HEIGHT=\"%1\"").arg( objbase->getAttribute(ATTR_HEIGHT).string() ) );
+ params.append( TQString::tqfromLatin1("HEIGHT=\"%1\"").arg( objbase->getAttribute(ATTR_HEIGHT).string() ) );
else if (embed && !embed->getAttribute(ATTR_HEIGHT).isEmpty()) {
- params.append( TQString::fromLatin1("HEIGHT=\"%1\"").arg( embed->getAttribute(ATTR_HEIGHT).string() ) );
+ params.append( TQString::tqfromLatin1("HEIGHT=\"%1\"").arg( embed->getAttribute(ATTR_HEIGHT).string() ) );
objbase->setAttribute(ATTR_HEIGHT, embed->getAttribute(ATTR_HEIGHT));
}
@@ -808,7 +808,7 @@ void RenderPartObject::updateWidget()
serviceType = "application/x-activex-handler";
#endif
- if(classId.find(TQString::fromLatin1("D27CDB6E-AE6D-11cf-96B8-444553540000")) >= 0) {
+ if(classId.tqfind(TQString::tqfromLatin1("D27CDB6E-AE6D-11cf-96B8-444553540000")) >= 0) {
// It is ActiveX, but the nsplugin system handling
// should also work, that's why we don't override the
// serviceType with application/x-activex-handler
@@ -817,17 +817,17 @@ void RenderPartObject::updateWidget()
// with nspluginviewer (Niko)
serviceType = "application/x-shockwave-flash";
}
- else if(classId.find(TQString::fromLatin1("CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA")) >= 0)
+ else if(classId.tqfind(TQString::tqfromLatin1("CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA")) >= 0)
serviceType = "audio/x-pn-realaudio-plugin";
- else if(classId.find(TQString::fromLatin1("8AD9C840-044E-11D1-B3E9-00805F499D93")) >= 0 ||
- objbase->classId.find(TQString::fromLatin1("CAFEEFAC-0014-0000-0000-ABCDEFFEDCBA")) >= 0)
+ else if(classId.tqfind(TQString::tqfromLatin1("8AD9C840-044E-11D1-B3E9-00805F499D93")) >= 0 ||
+ objbase->classId.tqfind(TQString::tqfromLatin1("CAFEEFAC-0014-0000-0000-ABCDEFFEDCBA")) >= 0)
serviceType = "application/x-java-applet";
// http://www.apple.com/quicktime/tools_tips/tutorials/activex.html
- else if(classId.find(TQString::fromLatin1("02BF25D5-8C17-4B23-BC80-D3488ABDDC6B")) >= 0)
+ else if(classId.tqfind(TQString::tqfromLatin1("02BF25D5-8C17-4B23-BC80-D3488ABDDC6B")) >= 0)
serviceType = "video/quicktime";
// http://msdn.microsoft.com/library/en-us/dnwmt/html/adding_windows_media_to_web_pages__etse.asp?frame=true
- else if(objbase->classId.find(TQString::fromLatin1("6BF52A52-394A-11d3-B153-00C04F79FAA6")) >= 0 ||
- classId.find(TQString::fromLatin1("22D6f312-B0F6-11D0-94AB-0080C74C7E95")) >= 0)
+ else if(objbase->classId.tqfind(TQString::tqfromLatin1("6BF52A52-394A-11d3-B153-00C04F79FAA6")) >= 0 ||
+ classId.tqfind(TQString::tqfromLatin1("22D6f312-B0F6-11D0-94AB-0080C74C7E95")) >= 0)
serviceType = "video/x-msvideo";
else
@@ -900,7 +900,7 @@ bool RenderPartObject::partLoadingErrorNotify( khtml::ChildFrame *childFrame, co
void RenderPartObject::slotPartLoadingErrorNotify()
{
// First we need to find out the servicetype - again - this code is too duplicated !
HTMLEmbedElementImpl *embed = 0;
TQString serviceType;
if( element()->id()==ID_OBJECT ) {
@@ -974,7 +974,7 @@ void RenderPartObject::slotPartLoadingErrorNotify()
deref();
}
-void RenderPartObject::layout( )
+void RenderPartObject::tqlayout( )
{
KHTMLAssert( needsLayout() );
KHTMLAssert( minMaxKnown() );
@@ -982,7 +982,7 @@ void RenderPartObject::layout( )
calcWidth();
calcHeight();
- RenderPart::layout();
+ RenderPart::tqlayout();
setNeedsLayout(false);
}
@@ -308,7 +308,7 @@ void RenderFrameSet::layout( )
gridLayout[gridLen - 1] += remainingLen[k];
}
- // now we have the final layout, distribute the delta over it
+ // now we have the final tqlayout, distribute the delta over it
bool worked = true;
for (int i = 0; i < gridLen; ++i) {
@@ -641,7 +641,7 @@ void RenderPart::setWidget( TQWidget *widget )
setNeedsLayoutAndMinMaxRecalc();
// make sure the scrollbars are set correctly for restore
- // ### find better fix
+ // ### tqfind better fix
slotViewCleared();
}
@@ -900,7 +900,7 @@ bool RenderPartObject::partLoadingErrorNotify( khtml::ChildFrame *childFrame, co
void RenderPartObject::slotPartLoadingErrorNotify()
{
- // First we need to find out the servicetype - again - this code is too duplicated !
+ // First we need to tqfind out the servicetype - again - this code is too duplicated !
HTMLEmbedElementImpl *embed = 0;
TQString serviceType;